// Persistence of Vision Ray Tracer Scene Description File
// File: solar-system_orrery_two.pov
// Vers: 3.6
// Desc: Solar System orrery, scaled simulation of planets
// Date: 2009.035; 2009.07
// Auth: bob hughes
// Note: this is free to use and modify without credit given

/*
Notes about scale used, and most importantly expect inaccuracies and errors. Data from wikipedia.org.

Inner planets (Mercury, Venus, Earth/Moon, Mars) are 4:1 of outer "gas giant" planets (Jupiter, Saturn, Uranus, Neptune);

Dwarf planets (Pluto/Charon, Ceres, Eris) are 4:1 of Earth, or 16:1 of Jupiter.

Sun is 1:50 (or 1/50th) scale of inner planets, or 1:12.5 of gas giant planets.

Orbit scale of inner planets is 1:1500 of their respective planet sizes;

Jupiter orbit is 1:750 of the gas giants' diameter scale, Saturn orbit is 1:1000, Uranus 1:1500, Neptune 1:2000 (also Pluto 1:2000).

Pluto orbit scale is 1:5.333 of Earth orbit scale, or 1:2.667 of Jupiter orbit scale, 1:2 of Uranus and 1:1 of Neptune.

Moon orbit distance scale is 1:25, Charon orbit distance is 1:4, relative their diameters (not solar system scale).

Numbers used for sun/planet/moon/asteroid diameters are double that of orbit distances, hence this remark to clarify that.

Camera does not move closer or farther (metric/standard switch accomodates scale difference), only FOV changes.

camera (near end of file) is set up for square images.
*/

//cmd:-w640 -h640 +a -ki0 -kf1 -kfi1 -kff50 Work_Threads=2

/* ************************************************************************************************************************************ */
// number of planet (Earth=3), 0 for Sun, 4.5 for asteroid Ceres; -1 Moon, -3 Earth. Also 10 for Eris (dwarf planet).
#local ViewPoint = 3;

/* greater than 0 and higher than 1 possible (>1.25 needed for Pluto aphelion, >1.6 for Eris aphelion, when Sun is ViewPoint),
smaller number magnifies view (0.03 Earth/Moon) and larger widens view (1 for whole solar system at Years=0). */
#local Zoom = 2/3; // when ViewPoint=0 (Sun) all planets seen with Zoom=1 at Years=0, 1/3 shows inner planets out to Jupiter.

/* degrees above (rotated around <0,0,0>) ecliptic */
#local ViewElevation = 0; // 0 side view, 90 overhead view (negative numbers or >90 perfectly acceptable yet possibly disorienting).

/* degrees sideways (rotated around <0,0,0>) */
#local ViewAzimuth = 0; // 0 to 360 turn in same direction as Earth orbits Sun (if + positive)

// number of years, or fraction of year, and for animation use clock keyword (can be any positive range).
#local Years = 29.5/2*clock;
/* 0.7625+(0.0125*clock) for moon shadow on earth, clock*(29.530588/365.2424) for 1 moon orbit, clock*(25.38/365.25) for 1 sun rotation.
196.05+clock*0.05 for Pluto eclipsing Sun while orbiting near default camera location (ViewPoint=0 Zoom=1 ViewElevation=0 ViewAzimuth=0 */

// metric or standard
#local Metric = no;

// prevents unwanted shadows cast between planets (also speeds render), need to specify a ViewPoint to keep a planet.
#local RemoveExtraPlanets = yes;

// use air or not (Earth)
#local Atmosphere = no;

// use clouds (Earth and Venus)
#local Clouds = yes;

// show orbits
#local ShowOrbitalPlanes = no;

// orbit transparency (0 to 1)
#local OrbitalPlanesTransparency = 0.98;

// use photons or not (untested)
#local Photons = no;

// use parallel sunlight (untested)
#local ParallelLight = no;

/* ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ */
// No scale unity here (yet), only some parts have the same scale.
/*
These numbers are divided into diameters and orbit distances. Larger scale when using smaller numbers.
 1 for all orbits would be real dimensions, while at the same time 0.5 for sun/planet/moon diameters is needed to match.
Actual unscaled size might not be viewed properly. 
*/

// to create scale of Sun.
#local SunScale=1e5;

// to create scale of inner planets Mercury, Venus, Earth/Moon, Mars.
#local InnerPlanetsScale=2000;

// to create scale of inner orbits Mercury, Venus, Earth, Mars.
#local InnerOrbitsScale=1.5e6;

// to create scale of orbit for Earth/Moon.
#local MoonOrbitScale=2.5e4;

// to create scale of gas giant planets Jupiter, Saturn, Uranus, Neptune.
#local GasGiantPlanetsScale=8000;

// to create scale of orbit for asteroids (Ceres).
#local AsteroidOrbitsScale=2e6;

// to create scale of orbit for Jupiter.
#local JupiterOrbitScale=3e6;

// to create scale of orbit for Saturn.
#local SaturnOrbitScale=4e6;

// to create scale of orbit for Uranus.
#local UranusOrbitScale=6e6;

// to create scale of orbits for Neptune, Pluto, Eris.
#local OuterOrbitsScale=8e6;

// to create scale of dwarf planets Ceres, Pluto/Charon, Eris.
#local DwarfPlanetsScale=500;

// to create scale of orbit for Pluto/Charon.
#local CharonOrbitScale=1000;

// to create scale of orbit for Eris/Dysnomia.
#local DysnomiaOrbitScale=1000;

// to create scale of moons Ganymede, Titan, Oberon, Triton.
#local MoonsScale=100;

// to change distance of viewpoint.
#local ViewScale=1;

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% */

// number of days in year
#local EarthYear = 365.256366;

/* 0.985609105 correction for Earth orbit to make only one complete 360 degree circle. */
#local Time = EarthYear*0.985609105*Years;

global_settings
{
#if (version<3.7)
	assumed_gamma 1
#end
	//ambient_light 1
#if (Photons=yes)
	photons
	{
		//count 20000
		spacing 0.01
		media 50
	}
#end
}

/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

#if (RemoveExtraPlanets=yes)

#switch (ViewPoint)

#case (-3)

#declare Earth=
// EARTH
/*
rotation 1 day (0.99726968 day sidereal, or 23.93447232 hours); tilt 23.439281; orbit 29.783 km/sec; 365.256366 days;
inclination 0 (ecliptic, or 134'43.3" {J2000} to invariable plane); ascending node 348.73936; arg. perihelion 114.20783;
precession of tilt 25765 years
*/
#if (Atmosphere=yes) // not fact-based
union
{
sphere
{
	0,
	#if (Metric=no)
	7960/InnerPlanetsScale
	#else
	12810/InnerPlanetsScale
	#end
	pigment
	{
		rgbt 1
	}
	interior
	{
		ior 1.0003
		media
		{
			absorption <0.01,0.2,0.3> // ?
			scattering
			{
				1,
				1-<0.05,0.8,0.99> // ?
			}
			density
			{
				spherical
				density_map
				{
					[0 rgb 0]
					[0.0095 rgb 1/10] // ?
					[0.0125 rgb 10] // ?
				}
				#if (Metric=no)
				scale InnerPlanetsScale/7960
				#else
				scale InnerPlanetsScale/12810
				#end
			}
		}
	}
	hollow on
}
#end
sphere
{
	0,
	#if (Metric=no)
	7860/InnerPlanetsScale
	#else
	12756/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			#if (Atmosphere=yes|Clouds=yes)
			"earth_real-map"
			#else
			"earth-map"
			#end
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.6
		specular 0.15 roughness 0.025
	}
#if (Atmosphere=yes)
}
#end
	rotate <0,-Time*EarthYear,0> // rotation
	rotate 23.439281*x // tilt
	#if (Metric=no)
	translate 2902/InnerPlanetsScale*-x // barycenter or offset due to moon
	#else
	translate 4670/InnerPlanetsScale*-x // barycenter or offset due to moon
	#end
	rotate 5.15*z // orbit inclination (due to Earth/Moon barycenter orbit)
}

object
{
	Earth
	rotate <0,Time,0>  // anti-motion to retain tilt orientation
	#if (Metric=no)
	translate (94509130+91402506)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (152097701+147098074)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*-y
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion
	#end
#if (Photons=yes)
	photons
	{
		target
		reflection off
		refraction on
		collect on
	}
#end
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(94509130+91402506)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(152097701+147098074)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(67693488+66782651)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(108942109+107476259)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 455418.5/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 732925/InnerOrbitsScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <0,1,1,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
no_shadow
}
#end

#break

#case (-1)

#declare Moon=
//MOON
/*
rotation 27.3217 days; tilt 6.688; orbit 1 km/sec; 27.3217 days (29.53 days synodic); inclination 5.15 (18.28 to 28.58 to Earth's equator, 1.53 from ecliptic);
eccentricity 0.0549; ascending node (?) August 28, 2007; descending node (?) March 3, 2007;
precession of orbit 6793 days; recession rate from Earth 3.8 cm/year; 
*/
sphere
{
	0,
	#if (Metric=no)
	2160/InnerPlanetsScale
	#else
	3476/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"moon-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.5
		specular 0.009 roughness 0.03
	}
	rotate <-6.688,Time*(EarthYear/27.3217),0> // anti-motion to retain tilt orientation (-6.688?)
	#if (Metric=no)
	translate (251655+225558)/2/MoonOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (384400+363000)/2/MoonOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/27.3217)*-y // revolution (around Earth)
	#if (Metric=no)
	translate 13048.5/MoonOrbitScale*-x // mi move to perigee
	#else
	translate 21000/MoonOrbitScale*-x // km move to perigee
	#end
	rotate (23.5+5.15)*z // inclination
}

object
{
	Moon
	// plus Earth location
	rotate <0,Time,0> // anti-motion to retain tilt orientation
	#if (Metric=no)
	translate (94509130+91402506)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (152097701+147098074)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*-y // revolution (around Sun)
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion
	#end
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(251655+225558)/2/MoonOrbitScale // mi aphelion and perihelion average
	#else
	(384400+363000)/2/MoonOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 13048.5/MoonOrbitScale*-x // mi move to perigee
	#else
	translate 21000/MoonOrbitScale*-x // km move to perigee
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	7860/InnerPlanetsScale
	#else
	12756/InnerPlanetsScale
	#end
	#if (Metric=no)
	translate 2902/InnerPlanetsScale
	#else
	translate 4670/InnerPlanetsScale
	#end
}
pigment
{
	rgbt <0.75,0.75,0.75,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate (23.5+5.15)*z // inclination
	rotate <0,Time,0> // anti-motion to retain tilt orientation
	#if (Metric=no)
	translate (94509130+91402506)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (152097701+147098074)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion
	#end
	rotate Time*-y // revolution (around Sun)
no_shadow
}
#end

#break

#case (0)

// Sun chosen

#break

#case (1)

#declare Mercury=
// MERCURY
/*
rotation 58.646 days; tilt 0; orbit 47.87 km/sec; 87.969 days;
inclination 7.005 (3.38 Sun's equator); ascending node 48.331; arg. perihelion 29.124;
*/
sphere
{
	0,
	#if (Metric=no)
	3032/InnerPlanetsScale
	#else
	4880/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"mercury-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.5
		specular 0.01 roughness 0.1
	}
	rotate Time*(EarthYear/58.646)*-y // rotation
	rotate <0,Time*(EarthYear/87.969),0> // anti-revolution and tilt (negligible for Mercury)
	#if (Metric=no)
	translate (43382210+28583820)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (69816900+46001200)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/87.969)*-y // revolution
	#if (Metric=no)
	translate 7399195/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 11907850/InnerOrbitsScale*-x // km move to perihelion
	#end
	rotate 7.005*z // orbit inclination
}

object
{
	Mercury
}

#if (ShowOrbitalPlanes=yes)
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(43382210+28583820)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(69816900+46001200)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 7399195/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 11907850/InnerOrbitsScale*-x // km move to perihelion
	#end
	pigment
	{
		rgbt <0.5,0.5,0.5,OrbitalPlanesTransparency>
	}
	finish
	{
		ambient 1 diffuse 0
	}
	rotate 7.005*z // orbit inclination
no_shadow
}
#end

#break

#case (2)

#declare Venus=
// VENUS
/*
rotation 243.0185 days; tilt 177.3; orbit 35.02 km/sec; 224.70069 days;
inclination 3.39471; ascending node 76.67069; arg. perihelion 54.85229;
*/
sphere
{
	0,
	#if (Metric=no)
	7521/InnerPlanetsScale
	#else
	12104/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			#if (Atmosphere=yes|Clouds=yes)
			"venus-clouds"
			#else
			"venus-map"
			#end
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.7
		specular 0.05 roughness 0.1
	}
	rotate Time*(EarthYear/243.0185)*-y // rotation
	rotate <177.3,Time*(EarthYear/224.70069),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (67693488+66782651)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (108942109+107476259)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/224.70069)*-y // revolution
	#if (Metric=no)
	translate 455418.5/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 732925/InnerOrbitsScale*-x // km move to perihelion point
	#end
	rotate 3.39471*z // orbit inclination
}

object
{
	Venus
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(67693488+66782651)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(108942109+107476259)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 455418.5/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 732925/InnerOrbitsScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(43382210+28583820)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(69816900+46001200)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 7399195/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 11907850/InnerOrbitsScale*-x // km move to perihelion
	#end
}
pigment
{
	rgbt <0.5,1,0,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 3.39471*z // orbit inclination
no_shadow
}
#end

#break

#case (3)

#declare Earth=
// EARTH
/*
rotation 1 day (0.99726968 day sidereal, or 23.93447232 hours); tilt 23.439281; orbit 29.783 km/sec; 365.256366 days;
inclination 0 (ecliptic, or 134'43.3" {J2000} to invariable plane); ascending node 348.73936; arg. perihelion 114.20783;
precession of tilt 25765 years
*/
#if (Atmosphere=yes) // not fact-based
union
{
sphere
{
	0,
	#if (Metric=no)
	7960/InnerPlanetsScale
	#else
	12810/InnerPlanetsScale
	#end
	pigment
	{
		rgbt 1
	}
	interior
	{
		ior 1.0003
		media
		{
			absorption <0.01,0.2,0.3> // ?
			scattering
			{
				1,
				1-<0.05,0.8,0.99> // ?
			}
			density
			{
				spherical
				density_map
				{
					[0 rgb 0]
					[0.0095 rgb 1/10] // ?
					[0.0125 rgb 10] // ?
				}
				#if (Metric=no)
				scale 7960/InnerPlanetsScale
				#else
				scale 12810/InnerPlanetsScale
				#end
			}
		}
	}
	hollow on
}
#end
sphere
{
	0,
	#if (Metric=no)
	7860/InnerPlanetsScale
	#else
	12756/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			#if (Atmosphere=yes|Clouds=yes)
			"earth_real-map"
			#else
			"earth-map"
			#end
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.6
		specular 0.15 roughness 0.025
	}
#if (Atmosphere=yes)
}
#end
	rotate <0,-Time*EarthYear,0> // rotation
	rotate 23.439281*x // tilt
	#if (Metric=no)
	translate 2902/InnerPlanetsScale*-x
	#else
	translate 4670/InnerPlanetsScale*-x
	#end
	rotate 5.15*z // orbit inclination (due to Moon and Earth barycenter)
}

#declare Moon=
//MOON
/*
rotation 27.3217 days; tilt 6.688; orbit 1 km/sec; 27.3217 days (29.53 days synodic); inclination 5.15 (18.28 to 28.58 to Earth's equator, 1.53 from ecliptic);
eccentricity 0.0549; ascending node (?) August 28, 2007; descending node (?) March 3, 2007;
precession of orbit 6793 days; recession rate from Earth 3.8 cm/year; 
*/
sphere
{
	0,
	#if (Metric=no)
	2160/InnerPlanetsScale
	#else
	3476/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"moon-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.5
		specular 0.009 roughness 0.03
	}

	rotate <-6.688,Time*(EarthYear/27.3217),0> // orbit anti-motion (for axial tilt hold) {uncertain about x rotation here}
	//rotate 6.688*-z // tilt??
	#if (Metric=no)
	translate (251655+225558)/2/MoonOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (384400+363000)/2/MoonOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/27.3217)*-y // revolution (around Earth)
	#if (Metric=no)
	translate 13048.5/MoonOrbitScale*-x // mi move to perihelion point
	#else
	translate 21000/MoonOrbitScale*-x // km move to perihelion point
	#end
	rotate (23.5+5.15)*z // orbit inclination
}

#declare EarthMoon=
// EARTH/MOON
union
{
object
{
	Earth
}
object
{
	Moon
}
	rotate <0,Time,0> // orbit anti-motion (for axial tilt hold) {axial tilt (z rotation) pre-stated for Earth/Moon}
	#if (Metric=no)
	translate (94509130+91402506)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (152097701+147098074)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*-y // revolution
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion point
	#end
#if (Photons=yes)
	photons
	{
		target
		reflection off
		refraction on
		collect on
	}
#end
}

object
{
	EarthMoon
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(94509130+91402506)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(152097701+147098074)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(67693488+66782651)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(108942109+107476259)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 455418.5/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 732925/InnerOrbitsScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <0,1,1,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
no_shadow
}
#end

#break

#case (4)

#declare Mars=
// MARS
/*
rotation 1.025957 days; tilt 25.19; orbit 24.077 km/sec; 686.971 days;
inclination 1.85 (5.65 Sun's equator); ascending node 49.562; arg. perihelion 286.537;
*/
sphere
{
	0,
	#if (Metric=no)
	4220/InnerPlanetsScale
	#else
	6792/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"mars-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.6
		specular 0.02 roughness 0.1
	}
	rotate Time*(EarthYear/1.025957)*-y // rotation
	rotate <25.19,Time*(EarthYear/686.971),0> // orbit anti-motion (for axial tilt hold) and axial tilt (x rotation)
	#if (Metric=no)
	translate (154851480+128418163)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (249209300+206669000)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/686.971)*-y // revolution
	#if (Metric=no)
	translate 13216658.5/InnerOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 21270150/InnerOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
	rotate 1.85*z // orbital inclination
}

object
{
	Mars
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(154851480+128418163)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(249209300+206669000)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 13216658.5/InnerOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 21270150/InnerOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(94509130+91402506)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(152097701+147098074)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <1,0.5,0,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 1.85*z // orbital inclination
no_shadow
}
#end

#break

#case (4.5)

#declare Ceres=
// CERES 
/*
rotation 0.3781 days; tilt 3; orbit 17.882 km/sec; 1679.819 days;
inclination 10.586712; ascending node 80.40696; arg. perihelion 73.15073
*/
sphere
{
	0,
	#if (Metric=no)
	302.8/DwarfPlanetsScale // 282.5 polar radius mi
	#else
	487.3/DwarfPlanetsScale // 454.7 polar radius km
	#end
	pigment
	{
		image_map
		{
			jpeg
			"ceres-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.6
		specular 0.02 roughness 0.1
	}
	rotate Time*(EarthYear/0.3781)*-y // rotation
	rotate <3,Time*(EarthYear/1679.819),0> // orbit anti-motion (for axial tilt hold) and axial tilt (x rotation)
	#if (Metric=no)
	translate (278273734+237003140)/2/AsteroidOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (447838164+381419582)/2/AsteroidOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/1679.819)*-y // revolution
	#if (Metric=no)
	translate 20635297/AsteroidOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 33209291/AsteroidOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
	rotate 10.586712*z // orbital inclination
}

object
{
	Ceres
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(278273734+237003140)/2/AsteroidOrbitsScale // mi aphelion and perihelion average
	#else
	(447838164+381419582)/2/AsteroidOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 20635297/AsteroidOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 33209291/AsteroidOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(154851480+128418163)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(249209300+206669000)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 13216658.5/InnerOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 21270150/InnerOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
}
pigment
{
	rgbt <1,0.5,0.5,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 10.586712*z // orbital inclination
no_shadow
}
#end

#break

#case (5)

#declare Jupiter=
// JUPITER
/*
rotation 0.413541667 day; tilt 3.13; orbit 13.07 km/sec; 4331.572 days;
inclination 1.305 (6.09 Sun's equator); ascending node 100.492; arg. perihelion 275.066;
*/
sphere
{
	0,
	#if (Metric=no)
	88846/GasGiantPlanetsScale // 41541 polar radius
	#else
	142984/GasGiantPlanetsScale // 66854 polar radius
	#end
	pigment
	{
		image_map
		{
			jpeg
			"jupiter-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.8
		specular 0.04 roughness 0.1
	}
	scale <1.0125,0.9875,1> // flattening (not fact-based)
	rotate Time*(EarthYear/0.413541667)*-y // rotation
	rotate <3.13,Time*(EarthYear/4331.572),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (507362503+460148731)/2/JupiterOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (816520800+740537600)/2/JupiterOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/4331.572)*-y // revolution
	#if (Metric=no)
	translate 23606886/JupiterOrbitScale*-x // mi move to perihelion point
	#else
	translate 37991600/JupiterOrbitScale*-x // km move to perihelion point
	#end
	rotate 1.305*z // orbit inclination
}

object
{
	Jupiter
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(507362503+460148731)/2/JupiterOrbitScale // mi aphelion and perihelion average
	#else
	(816520800+740537600)/2/JupiterOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 23606886/JupiterOrbitScale*-x // mi move to perihelion point
	#else
	translate 37991600/JupiterOrbitScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(278273734+237003140)/2/AsteroidOrbitsScale // mi aphelion and perihelion average
	#else
	(447838164+381419582)/2/AsteroidOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 20635297/AsteroidOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 33209291/AsteroidOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
}
pigment
{
	rgbt <1,0,1,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 1.305*z // orbit inclination
no_shadow
}
#end

#break

#case (6)

#declare Saturn=
// SATURN
/*
rotation 0.444 day; tilt 26.73; orbit 9.69 km/sec; 10832.327 days;
inclination 2.48524 (5.51 Sun's equator); ascending node 113.642 811; arg. perihelion 336.013 862;
*/
union
{
sphere
{
	0,
	#if (Metric=no)
	74898/GasGiantPlanetsScale // polar radius 33780 mi
	#else
	120534/GasGiantPlanetsScale // polar radius 54364 km
	#end
	pigment
	{
		image_map
		{
			jpeg
			"saturn-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.8
		specular 0.04 roughness 0.1
	}
	scale <1.025,0.975,1> // flattening (not fact-based)
	rotate Time*(EarthYear/0.444)*-y // rotation
}
disc // rings (not fact-based)
{
	0,y,
	#if (Metric=no)
	155000/GasGiantPlanetsScale,
	55000/GasGiantPlanetsScale
	#else
	249448/GasGiantPlanetsScale,
	88514/GasGiantPlanetsScale
	#end
	pigment
	{
		onion
		color_map
		{
			[0.6 rgbt <0.75,0.5,0.25,1>]
			[0.75 rgbt <0.75,0.5,0.25,0>]
			[0.8 rgb <0.75,0.5,0.25>]
			[0.85 rgb <0.75,0.75,0.5>]
			[0.9125 rgb <0.75,0.75,0.5>]
			[0.925 rgbt 1]
			[0.95 rgbt 1]
			[0.967 rgb <0.75,0.75,0.25>]
		}
		#if (Metric=no)
		scale 155000/GasGiantPlanetsScale
		#else
		scale 249448/GasGiantPlanetsScale
		#end
	}
	finish
	{
		ambient 0.01 diffuse 0.9
		specular 0.06 roughness 0.03
	}
}
	rotate <26.73,Time*(EarthYear/10832.327),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (940337046+841071241)/2/SaturnOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (1513325783+1353572956)/2/SaturnOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/10832.327)*-y // revolution
	#if (Metric=no)
	translate 49632902.5/SaturnOrbitScale*-x // mi move to perihelion point
	#else
	translate 79876414/SaturnOrbitScale*-x // km move to perihelion point
	#end
	rotate 2.48524*z // orbit inclination
}

object
{
	Saturn
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(940337046+841071241)/2/SaturnOrbitScale // mi aphelion and perihelion average
	#else
	(1513325783+1353572956)/2/SaturnOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 49632902.5/SaturnOrbitScale*-x // mi move to perihelion point
	#else
	translate 79876414/SaturnOrbitScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(507362503+460148731)/2/JupiterOrbitScale // mi aphelion and perihelion average
	#else
	(816520800+740537600)/2/JupiterOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 23606886/JupiterOrbitScale*-x // mi move to perihelion point
	#else
	translate 37991600/JupiterOrbitScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <1,1,0,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 2.48524*z // orbit inclination
no_shadow
}
#end

#break

#case (7)

#declare Uranus=
// URANUS
/*
rotation -0.71833 day; tilt 97.77; orbit 6.81 km/sec; 30799.095 days;
inclination 0.772556 (6.48 sun's equator); ascending node 73.989821; arg. perihelion 96.541318;
*/
union
{
sphere
{
	0,
	#if (Metric=no)
	31763/GasGiantPlanetsScale // 31035 mi polar radius
	#else
	51118/GasGiantPlanetsScale // 49946 km polar radius
	#end
	pigment
	{
		image_map
		{
			jpeg
			"uranus-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.7
		specular 0.04 roughness 0.1
	}
	rotate Time*(EarthYear/0.71833)*-y // rotation
}
disc // rings (not fact-based)
{
	0,y,
	#if (Metric=no)
	64000/GasGiantPlanetsScale,
	44000/GasGiantPlanetsScale
	#else
	102998/GasGiantPlanetsScale,
	70811/GasGiantPlanetsScale
	#end
	pigment
	{
		onion
		color_map
		{
			[0.67 rgbt <0.5,0.5,0.25,1>]
			[0.7 rgbt <0.5,0.5,0.25,0>]
			[0.7 rgbt 1]
			[0.775 rgb 1]
			[0.8 rgb <0.5,0.5,0.25>]
			[0.825 rgbt 1]
			[0.85 rgbt 1]
			[0.875 rgb <0.5,0.5,0.5>]
			[0.9 rgb <0.5,0.5,0.5>]
			[0.9 rgbt 1]
			[0.975 rgbt 1]
			[1 rgb <0.5,0.5,0.25>]
		}
		#if (Metric=no)
		scale 64000/GasGiantPlanetsScale
		#else
		scale 102998/GasGiantPlanetsScale
		#end
	}
	finish
	{
		ambient 0.01 diffuse 0.2
		specular 0.02 roughness 0.08
	}
}
	transform
	{
	rotate <97.77,Time*(EarthYear/30799.095),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (1866859854+1708111169)/2/UranusOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (3004419704+2748938461)/2/UranusOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/30799.095)*-y // revolution
	#if (Metric=no)
	translate 79374342.5/UranusOrbitScale*-x // mi move to perihelion point
	#else
	translate 127740622/UranusOrbitScale*-x // km move to perihelion point
	#end
	rotate 0.772556*z // orbit inclination
	}
}

object
{
	Uranus
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(1866859854+1708111169)/2/UranusOrbitScale // mi aphelion and perihelion average
	#else
	(3004419704+2748938461)/2/UranusOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 49632902.5/SaturnOrbitScale*-x // mi move to perihelion point
	#else
	translate 79876414/SaturnOrbitScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(940337046+841071241)/2/SaturnOrbitScale // mi aphelion and perihelion average
	#else
	(1513325783+1353572956)/2/SaturnOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 49632902.5/SaturnOrbitScale*-x // mi move to perihelion point
	#else
	translate 79876414/SaturnOrbitScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <0,1,0.5,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 0.772556*z // orbit inclination
no_shadow
}
#end

#break

#case (8)

#declare Neptune=
// NEPTUNE
/*
rotation 0.6713 day; tilt 28.32; orbit 5.43 km/sec; 60190 days;
inclination 1.767975 (6.43 sun's equator); ascending node 131.794310; arg. perihelion 265.646853
*/
sphere
{
	0,
	#if (Metric=no)
	30775/GasGiantPlanetsScale // 30250 mi polar radius
	#else
	49528/GasGiantPlanetsScale // 48682 km polar radius
	#end
	pigment
	{
		image_map
		{
			jpeg
			"neptune-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.7
		specular 0.04 roughness 0.1
	}
	rotate Time*(EarthYear/0.6713)*-y // rotation
	rotate <28.32,Time*(EarthYear/60190),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (2829691160+2766929154)/2/OuterOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (4553946490+4452940833)/2/OuterOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/60190)*-y // revolution
	#if (Metric=no)
	translate 31381003/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 50502829/OuterOrbitsScale*-x // km move to perihelion point
	#end
	rotate 1.767975*z // orbit inclination
}

object
{
	Neptune
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(2829691160+2766929154)/2/OuterOrbitsScale // mi aphelion and perihelion average
	#else
	(4553946490+4452940833)/2/OuterOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 31381003/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 50502829/OuterOrbitsScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(1866859854+1708111169)/2/UranusOrbitScale // mi aphelion and perihelion average
	#else
	(3004419704+2748938461)/2/UranusOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 79374342.5/UranusOrbitScale*-x // mi move to perihelion point
	#else
	translate 127740622/UranusOrbitScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <0,0.5,1,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 1.767975*z // orbit inclination
no_shadow
}
#end

#break

#case (9)

#declare PlutoCharon=
// PLUTO/CHARON
union
{
// PLUTO
/*
rotation 6.387 days; tilt 119.591; orbit 4.666 km/sec; 90613.3 days;
inclination 17.14175 (11.88 sun's equator); ascending node 110.30347; arg. perihelion 113.76329;
*/
sphere
{
	0,
	#if (Metric=no)
	1485/DwarfPlanetsScale
	#else
	2390/DwarfPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"pluto-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.8
		specular 0.05 roughness 0.07
	}
	#if (Metric=no)
	translate 1264.5/CharonOrbitScale*-x // miles offset due to barycenter
	#else
	translate 2035/CharonOrbitScale*-x // kilometers offset due to barycenter
	#end
}
// CHARON
/*
rotation 6.387 days; tilt 112.783 to ecliptic (0.001 to Pluto's equator);
*/
sphere
{
	0,
	#if (Metric=no)
	750/DwarfPlanetsScale
	#else
	1207/DwarfPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"charon-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.7
		specular 0.04 roughness 0.08
	}
	#if (Metric=no)
	translate (12161-1264.5)/CharonOrbitScale*x // miles offset due to barycenter
	#else
	translate (19571-2035)/CharonOrbitScale*x // kilometers offset due to barycenter
	#end
}
	rotate <0,Time*(EarthYear/6.387),0> // planet/moon orbit
	rotate 119.591*x // Pluto/Charon mutual orbit inclination

	rotate <0,Time*(EarthYear/90613.3),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (4583000000+2757000000)/2/OuterOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (7376000000+4437000000)/2/OuterOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/90613.3)*-y // revolution
	#if (Metric=no)
	translate 913000000/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 1469331072/OuterOrbitsScale*-x // km move to perihelion point
	#end
	rotate 17.14175*z // orbit inclination
}

object
{
	PlutoCharon
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(4583000000+2757000000)/2/OuterOrbitsScale // mi aphelion and perihelion average
	#else
	(7376000000+4437000000)/2/OuterOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 913000000/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 1469331072/OuterOrbitsScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(2829691160+2766929154)/2/OuterOrbitsScale // mi aphelion and perihelion average
	#else
	(4553946490+4452940833)/2/OuterOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 31381003/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 50502829/OuterOrbitsScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <0,0,1,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 17.14175*z // orbit inclination
no_shadow
}
#end

#break

#case (10)

#declare Eris=
// ERIS/DYSNOMIA
union
{
// ERIS
/*
rotation 1/3 days; tilt ?; orbit 3.436 km/sec; 203334.675 days;
inclination 44.187; ascending node 35.8696; arg. perihelion 151.4305
*/
sphere
{
	0,
	#if (Metric=no)
	1677.7/DwarfPlanetsScale
	#else
	2700/DwarfPlanetsScale
	#end
	pigment
	{
		wrinkles
		color_map
		{
			[0 rgb <0.4,0.35,0.3>/2]
			[0.2 rgb <0.45,0.35,0.3>]
			[0.7 rgb <0.35,0.35,0.35>]
			[1 rgb <0.35,0.35,0.35>*2]
		}
		scale 0.75
	}
	finish
	{
		ambient 0.001 diffuse 0.6
		specular 0.03 roughness 0.09
	}
	rotate <0,Time*(EarthYear/0.333333),0> // rotation
}
// DYSNOMIA
sphere
{
	0,
	#if (Metric=no)
	124/DwarfPlanetsScale
	#else
	200/DwarfPlanetsScale
	#end
	pigment
	{
		wrinkles
		color_map
		{
			[0 rgb <0.4,0.4,0.4>/2]
			[0.3 rgb <0.45,0.35,0.35>]
			[0.6 rgb <0.3,0.25,0.2>]
			[1 rgb <0.3,0.25,0.2>*2]
		}
		scale 0.05
	}
	finish
	{
		ambient 0.001 diffuse 0.5
		specular 0.02 roughness 0.1
	}
	#if (Metric=no)
	translate 23221/DysnomiaOrbitScale*x // miles moon orbit distance
	#else
	translate 37370/DysnomiaOrbitScale*x // kilometers moon orbit distance
	#end
	rotate <0,Time*(EarthYear/15.774),142> // moon orbit revolution and inclination
}
	rotate <0,Time*(EarthYear/203334.675),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (9.072e9+3.51e9)/2/OuterOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (14.6e9+5.65e9)/2/OuterOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/203334.675)*-y // revolution
	#if (Metric=no)
	translate 2.781e9/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 4.4756e9/OuterOrbitsScale*-x // km move to perihelion point
	#end
	rotate 44.187*z // orbit inclination
}

object
{
	Eris
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(9.072e9+3.51e9)/2/OuterOrbitsScale // mi aphelion and perihelion average
	#else
	(14.6e9+5.65e9)/2/OuterOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 2.781e9/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 4.4756e9/OuterOrbitsScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(4583000000+2757000000)/2/OuterOrbitsScale // mi aphelion and perihelion average
	#else
	(7376000000+4437000000)/2/OuterOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 913000000/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 1469331072/OuterOrbitsScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <1,0,0,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 44.187*z // orbit inclination
no_shadow
}
#end

#break

#end // switch

// RemoveExtraPlanets=yes
#else
// RemoveExtraPlanets=no

/* &&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&& */

#switch (ViewPoint)

#case (-3)

#declare Earth=
// EARTH
/*
rotation 1 day (0.99726968 day sidereal, or 23.93447232 hours); tilt 23.439281; orbit 29.783 km/sec; 365.256366 days;
inclination 0 (ecliptic, or 134'43.3" {J2000} to invariable plane); ascending node 348.73936; arg. perihelion 114.20783;
precession of tilt 25765 years
*/
#if (Atmosphere=yes) // not fact-based
union
{
sphere
{
	0,
	#if (Metric=no)
	7960/InnerPlanetsScale
	#else
	12810/InnerPlanetsScale
	#end
	pigment
	{
		rgbt 1
	}
	interior
	{
		ior 1.0003
		media
		{
			absorption <0.01,0.2,0.3> // ?
			scattering
			{
				1,
				1-<0.05,0.8,0.99> // ?
			}
			density
			{
				spherical
				density_map
				{
					[0 rgb 0]
					[0.0095 rgb 1/10] // ?
					[0.0125 rgb 10] // ?
				}
				#if (Metric=no)
				scale InnerPlanetsScale/7960
				#else
				scale InnerPlanetsScale/12810
				#end
			}
		}
	}
	hollow on
}
#end
sphere
{
	0,
	#if (Metric=no)
	7860/InnerPlanetsScale
	#else
	12756/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			#if (Atmosphere=yes|Clouds=yes)
			"earth_real-map"
			#else
			"earth-map"
			#end
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.6
		specular 0.15 roughness 0.025
	}
#if (Atmosphere=yes)
}
#end
	rotate <0,-Time*EarthYear,0> // rotation
	rotate 23.439281*x // tilt
	#if (Metric=no)
	translate 2902/InnerPlanetsScale*-x // barycenter or offset due to moon
	#else
	translate 4670/InnerPlanetsScale*-x // barycenter or offset due to moon
	#end
	rotate 5.15*z // orbit inclination (due to Earth/Moon barycenter orbit)
}

object
{
	Earth
	rotate <0,Time,0>  // anti-motion to retain tilt orientation
	#if (Metric=no)
	translate (94509130+91402506)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (152097701+147098074)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*-y
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion
	#end
#if (Photons=yes)
	photons
	{
		target
		reflection off
		refraction on
		collect on
	}
#end
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(94509130+91402506)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(152097701+147098074)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(67693488+66782651)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(108942109+107476259)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 455418.5/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 732925/InnerOrbitsScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <0,1,1,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
no_shadow
}
#end

#break

#case (-1)

#declare Moon=
//MOON
/*
rotation 27.3217 days; tilt 6.688; orbit 1 km/sec; 27.3217 days (29.53 days synodic); inclination 5.15 (18.28 to 28.58 to Earth's equator, 1.53 from ecliptic);
eccentricity 0.0549; ascending node (?) August 28, 2007; descending node (?) March 3, 2007;
precession of orbit 6793 days; recession rate from Earth 3.8 cm/year; 
*/
sphere
{
	0,
	#if (Metric=no)
	2160/InnerPlanetsScale
	#else
	3476/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"moon-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.5
		specular 0.009 roughness 0.03
	}
	rotate <-6.688,Time*(EarthYear/27.3217),0> // anti-motion to retain tilt orientation (-6.688?)
	#if (Metric=no)
	translate (251655+225558)/2/MoonOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (384400+363000)/2/MoonOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/27.3217)*-y // revolution (around Earth)
	#if (Metric=no)
	translate 13048.5/MoonOrbitScale*-x // mi move to perigee
	#else
	translate 21000/MoonOrbitScale*-x // km move to perigee
	#end
	rotate (23.5+5.15)*z // inclination
}

object
{
	Moon
	// plus Earth location
	rotate <0,Time,0> // anti-motion to retain tilt orientation
	#if (Metric=no)
	translate (94509130+91402506)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (152097701+147098074)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*-y // revolution (around Sun)
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion
	#end
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(251655+225558)/2/MoonOrbitScale // mi aphelion and perihelion average
	#else
	(384400+363000)/2/MoonOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 13048.5/MoonOrbitScale*-x // mi move to perigee
	#else
	translate 21000/MoonOrbitScale*-x // km move to perigee
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	7860/InnerPlanetsScale
	#else
	12756/InnerPlanetsScale
	#end
	#if (Metric=no)
	translate 2902/InnerPlanetsScale
	#else
	translate 4670/InnerPlanetsScale
	#end
}
pigment
{
	rgbt <0.75,0.75,0.75,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate (23.5+5.15)*z // inclination
	rotate <0,Time,0> // anti-motion to retain tilt orientation
	#if (Metric=no)
	translate (94509130+91402506)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (152097701+147098074)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion
	#end
	rotate Time*-y // revolution (around Sun)
no_shadow
}
#end

#break

#case (0)

// Sun chosen

#break

#case (1)

#declare Mercury=
// MERCURY
/*
rotation 58.646 days; tilt 0; orbit 47.87 km/sec; 87.969 days;
inclination 7.005 (3.38 Sun's equator); ascending node 48.331; arg. perihelion 29.124;
*/
sphere
{
	0,
	#if (Metric=no)
	3032/InnerPlanetsScale
	#else
	4880/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"mercury-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.5
		specular 0.01 roughness 0.1
	}
	rotate Time*(EarthYear/58.646)*-y // rotation
	rotate <0,Time*(EarthYear/87.969),0> // anti-revolution and tilt (negligible for Mercury)
	#if (Metric=no)
	translate (43382210+28583820)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (69816900+46001200)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/87.969)*-y // revolution
	#if (Metric=no)
	translate 7399195/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 11907850/InnerOrbitsScale*-x // km move to perihelion
	#end
	rotate 7.005*z // orbit inclination
}

object
{
	Mercury
}

#if (ShowOrbitalPlanes=yes)
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(43382210+28583820)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(69816900+46001200)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 7399195/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 11907850/InnerOrbitsScale*-x // km move to perihelion
	#end
	pigment
	{
		rgbt <0.5,0.5,0.5,OrbitalPlanesTransparency>
	}
	finish
	{
		ambient 1 diffuse 0
	}
	rotate 7.005*z // orbit inclination
no_shadow
}
#end

#break

#case (2)

#declare Venus=
// VENUS
/*
rotation 243.0185 days; tilt 177.3; orbit 35.02 km/sec; 224.70069 days;
inclination 3.39471; ascending node 76.67069; arg. perihelion 54.85229;
*/
sphere
{
	0,
	#if (Metric=no)
	7521/InnerPlanetsScale
	#else
	12104/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			#if (Atmosphere=yes|Clouds=yes)
			"venus-clouds"
			#else
			"venus-map"
			#end
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.7
		specular 0.05 roughness 0.1
	}
	rotate Time*(EarthYear/243.0185)*-y // rotation
	rotate <177.3,Time*(EarthYear/224.70069),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (67693488+66782651)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (108942109+107476259)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/224.70069)*-y // revolution
	#if (Metric=no)
	translate 455418.5/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 732925/InnerOrbitsScale*-x // km move to perihelion point
	#end
	rotate 3.39471*z // orbit inclination
}

object
{
	Venus
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(67693488+66782651)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(108942109+107476259)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 455418.5/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 732925/InnerOrbitsScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(43382210+28583820)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(69816900+46001200)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 7399195/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 11907850/InnerOrbitsScale*-x // km move to perihelion
	#end
}
pigment
{
	rgbt <0.5,1,0,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 3.39471*z // orbit inclination
no_shadow
}
#end

#break

#case (3)

#declare Earth=
// EARTH
/*
rotation 1 day (0.99726968 day sidereal, or 23.93447232 hours); tilt 23.439281; orbit 29.783 km/sec; 365.256366 days;
inclination 0 (ecliptic, or 134'43.3" {J2000} to invariable plane); ascending node 348.73936; arg. perihelion 114.20783;
precession of tilt 25765 years
*/
#if (Atmosphere=yes) // not fact-based
union
{
sphere
{
	0,
	#if (Metric=no)
	7960/InnerPlanetsScale
	#else
	12810/InnerPlanetsScale
	#end
	pigment
	{
		rgbt 1
	}
	interior
	{
		ior 1.0003
		media
		{
			absorption <0.01,0.2,0.3> // ?
			scattering
			{
				1,
				1-<0.05,0.8,0.99> // ?
			}
			density
			{
				spherical
				density_map
				{
					[0 rgb 0]
					[0.0095 rgb 1/10] // ?
					[0.0125 rgb 10] // ?
				}
				#if (Metric=no)
				scale 7960/InnerPlanetsScale
				#else
				scale 12810/InnerPlanetsScale
				#end
			}
		}
	}
	hollow on
}
#end
sphere
{
	0,
	#if (Metric=no)
	7860/InnerPlanetsScale
	#else
	12756/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			#if (Atmosphere=yes|Clouds=yes)
			"earth_real-map"
			#else
			"earth-map"
			#end
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.6
		specular 0.15 roughness 0.025
	}
#if (Atmosphere=yes)
}
#end
	rotate <0,-Time*EarthYear,0> // rotation
	rotate 23.439281*x // tilt
	#if (Metric=no)
	translate 2902/InnerPlanetsScale*-x
	#else
	translate 4670/InnerPlanetsScale*-x
	#end
	rotate 5.15*z // orbit inclination (due to Moon and Earth barycenter)
}

#declare Moon=
//MOON
/*
rotation 27.3217 days; tilt 6.688; orbit 1 km/sec; 27.3217 days (29.53 days synodic); inclination 5.15 (18.28 to 28.58 to Earth's equator, 1.53 from ecliptic);
eccentricity 0.0549; ascending node (?) August 28, 2007; descending node (?) March 3, 2007;
precession of orbit 6793 days; recession rate from Earth 3.8 cm/year; 
*/
sphere
{
	0,
	#if (Metric=no)
	2160/InnerPlanetsScale
	#else
	3476/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"moon-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.5
		specular 0.009 roughness 0.03
	}

	rotate <-6.688,Time*(EarthYear/27.3217),0> // orbit anti-motion (for axial tilt hold) {uncertain about x rotation here}
	//rotate 6.688*-z // tilt??
	#if (Metric=no)
	translate (251655+225558)/2/MoonOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (384400+363000)/2/MoonOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/27.3217)*-y // revolution (around Earth)
	#if (Metric=no)
	translate 13048.5/MoonOrbitScale*-x // mi move to perihelion point
	#else
	translate 21000/MoonOrbitScale*-x // km move to perihelion point
	#end
	rotate (23.5+5.15)*z // orbit inclination
}

#declare EarthMoon=
// EARTH/MOON
union
{
object
{
	Earth
}
object
{
	Moon
}
	rotate <0,Time,0> // orbit anti-motion (for axial tilt hold) {axial tilt (z rotation) pre-stated for Earth/Moon}
	#if (Metric=no)
	translate (94509130+91402506)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (152097701+147098074)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*-y // revolution
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion point
	#end
#if (Photons=yes)
	photons
	{
		target
		reflection off
		refraction on
		collect on
	}
#end
}

object
{
	EarthMoon
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(94509130+91402506)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(152097701+147098074)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(67693488+66782651)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(108942109+107476259)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 455418.5/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 732925/InnerOrbitsScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <0,1,1,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
no_shadow
}
#end

#break

#case (4)

#declare Mars=
// MARS
/*
rotation 1.025957 days; tilt 25.19; orbit 24.077 km/sec; 686.971 days;
inclination 1.85 (5.65 Sun's equator); ascending node 49.562; arg. perihelion 286.537;
*/
sphere
{
	0,
	#if (Metric=no)
	4220/InnerPlanetsScale
	#else
	6792/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"mars-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.6
		specular 0.02 roughness 0.1
	}
	rotate Time*(EarthYear/1.025957)*-y // rotation
	rotate <25.19,Time*(EarthYear/686.971),0> // orbit anti-motion (for axial tilt hold) and axial tilt (x rotation)
	#if (Metric=no)
	translate (154851480+128418163)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (249209300+206669000)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/686.971)*-y // revolution
	#if (Metric=no)
	translate 13216658.5/InnerOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 21270150/InnerOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
	rotate 1.85*z // orbital inclination
}

object
{
	Mars
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(154851480+128418163)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(249209300+206669000)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 13216658.5/InnerOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 21270150/InnerOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(94509130+91402506)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(152097701+147098074)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <1,0.5,0,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 1.85*z // orbital inclination
no_shadow
}
#end

#break

#case (4.5)

#declare Ceres=
// CERES 
/*
rotation 0.3781 days; tilt 3; orbit 17.882 km/sec; 1679.819 days;
inclination 10.586712; ascending node 80.40696; arg. perihelion 73.15073
*/
sphere
{
	0,
	#if (Metric=no)
	302.8/DwarfPlanetsScale // 282.5 polar radius mi
	#else
	487.3/DwarfPlanetsScale // 454.7 polar radius km
	#end
	pigment
	{
		image_map
		{
			jpeg
			"ceres-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.6
		specular 0.02 roughness 0.1
	}
	rotate Time*(EarthYear/0.3781)*-y // rotation
	rotate <3,Time*(EarthYear/1679.819),0> // orbit anti-motion (for axial tilt hold) and axial tilt (x rotation)
	#if (Metric=no)
	translate (278273734+237003140)/2/AsteroidOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (447838164+381419582)/2/AsteroidOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/1679.819)*-y // revolution
	#if (Metric=no)
	translate 20635297/AsteroidOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 33209291/AsteroidOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
	rotate 10.586712*z // orbital inclination
}

object
{
	Ceres
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(278273734+237003140)/2/AsteroidOrbitsScale // mi aphelion and perihelion average
	#else
	(447838164+381419582)/2/AsteroidOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 20635297/AsteroidOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 33209291/AsteroidOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(154851480+128418163)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(249209300+206669000)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 13216658.5/InnerOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 21270150/InnerOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
}
pigment
{
	rgbt <1,0.5,0.5,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 10.586712*z // orbital inclination
no_shadow
}
#end

#break

#case (5)

#declare Jupiter=
// JUPITER
/*
rotation 0.413541667 day; tilt 3.13; orbit 13.07 km/sec; 4331.572 days;
inclination 1.305 (6.09 Sun's equator); ascending node 100.492; arg. perihelion 275.066;
*/
sphere
{
	0,
	#if (Metric=no)
	88846/GasGiantPlanetsScale // 41541 polar radius
	#else
	142984/GasGiantPlanetsScale // 66854 polar radius
	#end
	pigment
	{
		image_map
		{
			jpeg
			"jupiter-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.8
		specular 0.04 roughness 0.1
	}
	scale <1.0125,0.9875,1> // flattening (not fact-based)
	rotate Time*(EarthYear/0.413541667)*-y // rotation
	rotate <3.13,Time*(EarthYear/4331.572),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (507362503+460148731)/2/JupiterOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (816520800+740537600)/2/JupiterOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/4331.572)*-y // revolution
	#if (Metric=no)
	translate 23606886/JupiterOrbitScale*-x // mi move to perihelion point
	#else
	translate 37991600/JupiterOrbitScale*-x // km move to perihelion point
	#end
	rotate 1.305*z // orbit inclination
}

object
{
	Jupiter
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(507362503+460148731)/2/JupiterOrbitScale // mi aphelion and perihelion average
	#else
	(816520800+740537600)/2/JupiterOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 23606886/JupiterOrbitScale*-x // mi move to perihelion point
	#else
	translate 37991600/JupiterOrbitScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(278273734+237003140)/2/AsteroidOrbitsScale // mi aphelion and perihelion average
	#else
	(447838164+381419582)/2/AsteroidOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 20635297/AsteroidOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 33209291/AsteroidOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
}
pigment
{
	rgbt <1,0,1,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 1.305*z // orbit inclination
no_shadow
}
#end

#break

#case (6)

#declare Saturn=
// SATURN
/*
rotation 0.444 day; tilt 26.73; orbit 9.69 km/sec; 10832.327 days;
inclination 2.48524 (5.51 Sun's equator); ascending node 113.642 811; arg. perihelion 336.013 862;
*/
union
{
sphere
{
	0,
	#if (Metric=no)
	74898/GasGiantPlanetsScale // polar radius 33780 mi
	#else
	120534/GasGiantPlanetsScale // polar radius 54364 km
	#end
	pigment
	{
		image_map
		{
			jpeg
			"saturn-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.8
		specular 0.04 roughness 0.1
	}
	scale <1.025,0.975,1> // flattening (not fact-based)
	rotate Time*(EarthYear/0.444)*-y // rotation
}
disc // rings (not fact-based)
{
	0,y,
	#if (Metric=no)
	155000/GasGiantPlanetsScale,
	55000/GasGiantPlanetsScale
	#else
	249448/GasGiantPlanetsScale,
	88514/GasGiantPlanetsScale
	#end
	pigment
	{
		onion
		color_map
		{
			[0.6 rgbt <0.75,0.5,0.25,1>]
			[0.75 rgbt <0.75,0.5,0.25,0>]
			[0.8 rgb <0.75,0.5,0.25>]
			[0.85 rgb <0.75,0.75,0.5>]
			[0.9125 rgb <0.75,0.75,0.5>]
			[0.925 rgbt 1]
			[0.95 rgbt 1]
			[0.967 rgb <0.75,0.75,0.25>]
		}
		#if (Metric=no)
		scale 155000/GasGiantPlanetsScale
		#else
		scale 249448/GasGiantPlanetsScale
		#end
	}
	finish
	{
		ambient 0.01 diffuse 0.9
		specular 0.06 roughness 0.03
	}
}
	rotate <26.73,Time*(EarthYear/10832.327),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (940337046+841071241)/2/SaturnOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (1513325783+1353572956)/2/SaturnOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/10832.327)*-y // revolution
	#if (Metric=no)
	translate 49632902.5/SaturnOrbitScale*-x // mi move to perihelion point
	#else
	translate 79876414/SaturnOrbitScale*-x // km move to perihelion point
	#end
	rotate 2.48524*z // orbit inclination
}

object
{
	Saturn
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(940337046+841071241)/2/SaturnOrbitScale // mi aphelion and perihelion average
	#else
	(1513325783+1353572956)/2/SaturnOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 49632902.5/SaturnOrbitScale*-x // mi move to perihelion point
	#else
	translate 79876414/SaturnOrbitScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(507362503+460148731)/2/JupiterOrbitScale // mi aphelion and perihelion average
	#else
	(816520800+740537600)/2/JupiterOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 23606886/JupiterOrbitScale*-x // mi move to perihelion point
	#else
	translate 37991600/JupiterOrbitScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <1,1,0,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 2.48524*z // orbit inclination
no_shadow
}
#end

#break

#case (7)

#declare Uranus=
// URANUS
/*
rotation -0.71833 day; tilt 97.77; orbit 6.81 km/sec; 30799.095 days;
inclination 0.772556 (6.48 sun's equator); ascending node 73.989821; arg. perihelion 96.541318;
*/
union
{
sphere
{
	0,
	#if (Metric=no)
	31763/GasGiantPlanetsScale // 31035 mi polar radius
	#else
	51118/GasGiantPlanetsScale // 49946 km polar radius
	#end
	pigment
	{
		image_map
		{
			jpeg
			"uranus-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.7
		specular 0.04 roughness 0.1
	}
	rotate Time*(EarthYear/0.71833)*-y // rotation
}
disc // rings (not fact-based)
{
	0,y,
	#if (Metric=no)
	64000/GasGiantPlanetsScale,
	44000/GasGiantPlanetsScale
	#else
	102998/GasGiantPlanetsScale,
	70811/GasGiantPlanetsScale
	#end
	pigment
	{
		onion
		color_map
		{
			[0.67 rgbt <0.5,0.5,0.25,1>]
			[0.7 rgbt <0.5,0.5,0.25,0>]
			[0.7 rgbt 1]
			[0.775 rgb 1]
			[0.8 rgb <0.5,0.5,0.25>]
			[0.825 rgbt 1]
			[0.85 rgbt 1]
			[0.875 rgb <0.5,0.5,0.5>]
			[0.9 rgb <0.5,0.5,0.5>]
			[0.9 rgbt 1]
			[0.975 rgbt 1]
			[1 rgb <0.5,0.5,0.25>]
		}
		#if (Metric=no)
		scale 64000/GasGiantPlanetsScale
		#else
		scale 102998/GasGiantPlanetsScale
		#end
	}
	finish
	{
		ambient 0.01 diffuse 0.2
		specular 0.02 roughness 0.08
	}
}
	transform
	{
	rotate <97.77,Time*(EarthYear/30799.095),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (1866859854+1708111169)/2/UranusOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (3004419704+2748938461)/2/UranusOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/30799.095)*-y // revolution
	#if (Metric=no)
	translate 79374342.5/UranusOrbitScale*-x // mi move to perihelion point
	#else
	translate 127740622/UranusOrbitScale*-x // km move to perihelion point
	#end
	rotate 0.772556*z // orbit inclination
	}
}

object
{
	Uranus
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(1866859854+1708111169)/2/UranusOrbitScale // mi aphelion and perihelion average
	#else
	(3004419704+2748938461)/2/UranusOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 49632902.5/SaturnOrbitScale*-x // mi move to perihelion point
	#else
	translate 79876414/SaturnOrbitScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(940337046+841071241)/2/SaturnOrbitScale // mi aphelion and perihelion average
	#else
	(1513325783+1353572956)/2/SaturnOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 49632902.5/SaturnOrbitScale*-x // mi move to perihelion point
	#else
	translate 79876414/SaturnOrbitScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <0,1,0.5,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 0.772556*z // orbit inclination
no_shadow
}
#end

#break

#case (8)

#declare Neptune=
// NEPTUNE
/*
rotation 0.6713 day; tilt 28.32; orbit 5.43 km/sec; 60190 days;
inclination 1.767975 (6.43 sun's equator); ascending node 131.794310; arg. perihelion 265.646853
*/
sphere
{
	0,
	#if (Metric=no)
	30775/GasGiantPlanetsScale // 30250 mi polar radius
	#else
	49528/GasGiantPlanetsScale // 48682 km polar radius
	#end
	pigment
	{
		image_map
		{
			jpeg
			"neptune-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.7
		specular 0.04 roughness 0.1
	}
	rotate Time*(EarthYear/0.6713)*-y // rotation
	rotate <28.32,Time*(EarthYear/60190),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (2829691160+2766929154)/2/OuterOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (4553946490+4452940833)/2/OuterOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/60190)*-y // revolution
	#if (Metric=no)
	translate 31381003/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 50502829/OuterOrbitsScale*-x // km move to perihelion point
	#end
	rotate 1.767975*z // orbit inclination
}

object
{
	Neptune
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(2829691160+2766929154)/2/OuterOrbitsScale // mi aphelion and perihelion average
	#else
	(4553946490+4452940833)/2/OuterOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 31381003/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 50502829/OuterOrbitsScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(1866859854+1708111169)/2/UranusOrbitScale // mi aphelion and perihelion average
	#else
	(3004419704+2748938461)/2/UranusOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 79374342.5/UranusOrbitScale*-x // mi move to perihelion point
	#else
	translate 127740622/UranusOrbitScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <0,0.5,1,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 1.767975*z // orbit inclination
no_shadow
}
#end

#break

#case (9)

#declare PlutoCharon=
// PLUTO/CHARON
union
{
// PLUTO
/*
rotation 6.387 days; tilt 119.591; orbit 4.666 km/sec; 90613.3 days;
inclination 17.14175 (11.88 sun's equator); ascending node 110.30347; arg. perihelion 113.76329;
*/
sphere
{
	0,
	#if (Metric=no)
	1485/DwarfPlanetsScale
	#else
	2390/DwarfPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"pluto-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.8
		specular 0.05 roughness 0.07
	}
	#if (Metric=no)
	translate 1264.5/CharonOrbitScale*-x // miles offset due to barycenter
	#else
	translate 2035/CharonOrbitScale*-x // kilometers offset due to barycenter
	#end
}
// CHARON
/*
rotation 6.387 days; tilt 112.783 to ecliptic (0.001 to Pluto's equator);
*/
sphere
{
	0,
	#if (Metric=no)
	750/DwarfPlanetsScale
	#else
	1207/DwarfPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"charon-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.7
		specular 0.04 roughness 0.08
	}
	#if (Metric=no)
	translate (12161-1264.5)/CharonOrbitScale*x // miles offset due to barycenter
	#else
	translate (19571-2035)/CharonOrbitScale*x // kilometers offset due to barycenter
	#end
}
	rotate <0,Time*(EarthYear/6.387),0> // planet/moon orbit
	rotate 119.591*x // Pluto/Charon mutual orbit inclination

	rotate <0,Time*(EarthYear/90613.3),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (4583000000+2757000000)/2/OuterOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (7376000000+4437000000)/2/OuterOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/90613.3)*-y // revolution
	#if (Metric=no)
	translate 913000000/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 1469331072/OuterOrbitsScale*-x // km move to perihelion point
	#end
	rotate 17.14175*z // orbit inclination
}

object
{
	PlutoCharon
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(4583000000+2757000000)/2/OuterOrbitsScale // mi aphelion and perihelion average
	#else
	(7376000000+4437000000)/2/OuterOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 913000000/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 1469331072/OuterOrbitsScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(2829691160+2766929154)/2/OuterOrbitsScale // mi aphelion and perihelion average
	#else
	(4553946490+4452940833)/2/OuterOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 31381003/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 50502829/OuterOrbitsScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <0,0,1,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 17.14175*z // orbit inclination
no_shadow
}
#end

#break

#case (10)

#declare Eris=
// ERIS/DYSNOMIA
union
{
// ERIS
/*
rotation 1/3 days; tilt ?; orbit 3.436 km/sec; 203334.675 days;
inclination 44.187; ascending node 35.8696; arg. perihelion 151.4305
*/
sphere
{
	0,
	#if (Metric=no)
	1677.7/DwarfPlanetsScale
	#else
	2700/DwarfPlanetsScale
	#end
	pigment
	{
		wrinkles
		color_map
		{
			[0 rgb <0.4,0.35,0.3>/2]
			[0.2 rgb <0.45,0.35,0.3>]
			[0.7 rgb <0.35,0.35,0.35>]
			[1 rgb <0.35,0.35,0.35>*2]
		}
		scale 0.75
	}
	finish
	{
		ambient 0.001 diffuse 0.6
		specular 0.03 roughness 0.09
	}
	rotate <0,Time*(EarthYear/0.333333),0> // rotation
}
// DYSNOMIA
sphere
{
	0,
	#if (Metric=no)
	124/DwarfPlanetsScale
	#else
	200/DwarfPlanetsScale
	#end
	pigment
	{
		wrinkles
		color_map
		{
			[0 rgb <0.4,0.4,0.4>/2]
			[0.3 rgb <0.45,0.35,0.35>]
			[0.6 rgb <0.3,0.25,0.2>]
			[1 rgb <0.3,0.25,0.2>*2]
		}
		scale 0.05
	}
	finish
	{
		ambient 0.001 diffuse 0.5
		specular 0.02 roughness 0.1
	}
	#if (Metric=no)
	translate 23221/DysnomiaOrbitScale*x // miles moon orbit distance
	#else
	translate 37370/DysnomiaOrbitScale*x // kilometers moon orbit distance
	#end
	rotate <0,Time*(EarthYear/15.774),142> // moon orbit revolution and inclination
}
	rotate <0,Time*(EarthYear/203334.675),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (9.072e9+3.51e9)/2/OuterOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (14.6e9+5.65e9)/2/OuterOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/203334.675)*-y // revolution
	#if (Metric=no)
	translate 2.781e9/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 4.4756e9/OuterOrbitsScale*-x // km move to perihelion point
	#end
	rotate 44.187*z // orbit inclination
}

object
{
	Eris
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(9.072e9+3.51e9)/2/OuterOrbitsScale // mi aphelion and perihelion average
	#else
	(14.6e9+5.65e9)/2/OuterOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 2.781e9/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 4.4756e9/OuterOrbitsScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(4583000000+2757000000)/2/OuterOrbitsScale // mi aphelion and perihelion average
	#else
	(7376000000+4437000000)/2/OuterOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 913000000/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 1469331072/OuterOrbitsScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <1,0,0,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 44.187*z // orbit inclination
no_shadow
}
#end

#break

#end // switch

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% */

#if (ViewPoint!=1)

#declare Mercury=
// MERCURY
/*
rotation 58.646 days; tilt 0; orbit 47.87 km/sec; 87.969 days;
inclination 7.005 (3.38 Sun's equator); ascending node 48.331; arg. perihelion 29.124;
*/
sphere
{
	0,
	#if (Metric=no)
	3032/InnerPlanetsScale
	#else
	4880/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"mercury-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.5
		specular 0.01 roughness 0.1
	}
	rotate Time*(EarthYear/58.646)*-y // rotation
	rotate <0,Time*(EarthYear/87.969),0> // anti-revolution and tilt (negligible for Mercury)
	#if (Metric=no)
	translate (43382210+28583820)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (69816900+46001200)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/87.969)*-y // revolution
	#if (Metric=no)
	translate 7399195/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 11907850/InnerOrbitsScale*-x // km move to perihelion
	#end
	rotate 7.005*z // orbit inclination
}

object
{
	Mercury
}

#if (ShowOrbitalPlanes=yes)
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(43382210+28583820)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(69816900+46001200)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 7399195/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 11907850/InnerOrbitsScale*-x // km move to perihelion
	#end
	pigment
	{
		rgbt <0.5,0.5,0.5,OrbitalPlanesTransparency>
	}
	finish
	{
		ambient 1 diffuse 0
	}
	rotate 7.005*z // orbit inclination
no_shadow
}
#end

#end

#if (ViewPoint!=2)

#declare Venus=
// VENUS
/*
rotation 243.0185 days; tilt 177.3; orbit 35.02 km/sec; 224.70069 days;
inclination 3.39471; ascending node 76.67069; arg. perihelion 54.85229;
*/
sphere
{
	0,
	#if (Metric=no)
	7521/InnerPlanetsScale
	#else
	12104/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			#if (Atmosphere=yes|Clouds=yes)
			"venus-clouds"
			#else
			"venus-map"
			#end
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.7
		specular 0.05 roughness 0.1
	}
	rotate Time*(EarthYear/243.0185)*-y // rotation
	rotate <177.3,Time*(EarthYear/224.70069),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (67693488+66782651)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (108942109+107476259)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/224.70069)*-y // revolution
	#if (Metric=no)
	translate 455418.5/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 732925/InnerOrbitsScale*-x // km move to perihelion point
	#end
	rotate 3.39471*z // orbit inclination
}

object
{
	Venus
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(67693488+66782651)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(108942109+107476259)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 455418.5/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 732925/InnerOrbitsScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(43382210+28583820)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(69816900+46001200)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 7399195/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 11907850/InnerOrbitsScale*-x // km move to perihelion
	#end
}
pigment
{
	rgbt <0,1,0,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 3.39471*z // orbit inclination
no_shadow
}
#end

#end

#if (ViewPoint!=3|ViewPoint!=-3)

#declare Earth=
// EARTH
/*
rotation 1 day (0.99726968 day sidereal, or 23.93447232 hours); tilt 23.439281; orbit 29.783 km/sec; 365.256366 days;
inclination 0 (ecliptic, or 134'43.3" {J2000} to invariable plane); ascending node 348.73936; arg. perihelion 114.20783;
precession of tilt 25765 years
*/
#if (Atmosphere=yes) // not fact-based
union
{
sphere
{
	0,
	#if (Metric=no)
	7960/InnerPlanetsScale
	#else
	12810/InnerPlanetsScale
	#end
	pigment
	{
		rgbt 1
	}
	interior
	{
		ior 1.0003
		media
		{
			absorption <0.01,0.2,0.3> // ?
			scattering
			{
				1,
				1-<0.05,0.8,0.99> // ?
			}
			density
			{
				spherical
				density_map
				{
					[0 rgb 0]
					[0.0095 rgb 1/10] // ?
					[0.0125 rgb 10] // ?
				}
				#if (Metric=no)
				scale 7960/InnerPlanetsScale
				#else
				scale 12810/InnerPlanetsScale
				#end
			}
		}
	}
	hollow on
}
#end
sphere
{
	0,
	#if (Metric=no)
	7860/InnerPlanetsScale
	#else
	12756/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			#if (Atmosphere=yes|Clouds=yes)
			"earth_real-map"
			#else
			"earth-map"
			#end
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.6
		specular 0.15 roughness 0.025
	}
#if (Atmosphere=yes)
}
#end
	rotate <0,-Time*EarthYear,0> // rotation
	rotate 23.439281*x // tilt
	#if (Metric=no)
	translate 2902/InnerPlanetsScale*-x // barycenter or offset due to moon
	#else
	translate 4670/InnerPlanetsScale*-x // barycenter or offset due to moon
	#end
	rotate 5.15*z // orbit inclination (due to Earth/Moon barycenter orbit)
}

object
{
	Earth
	rotate <0,Time,0>  // anti-motion to retain tilt orientation
	#if (Metric=no)
	translate (94509130+91402506)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (152097701+147098074)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*-y
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi
	#else
	translate 2499813/InnerOrbitsScale*-x // km
	#end

	photons
	{
		target
		reflection off
		refraction on
		collect on
	}

}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(94509130+91402506)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(152097701+147098074)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(67693488+66782651)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(108942109+107476259)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 455418.5/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 732925/InnerOrbitsScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <0,1,1,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
no_shadow
}
#end

#end

#if (ViewPoint!=-1|ViewPoint!=3)

#declare Moon=
//MOON
/*
rotation 27.3217 days; tilt 6.688; orbit 1 km/sec; 27.3217 days (29.53 days synodic); inclination 5.15 (18.28 to 28.58 to Earth's equator, 1.53 from ecliptic);
eccentricity 0.0549; ascending node (?) August 28, 2007; descending node (?) March 3, 2007;
precession of orbit 6793 days; recession rate from Earth 3.8 cm/year; 
*/
sphere
{
	0,
	#if (Metric=no)
	2160/InnerPlanetsScale
	#else
	3476/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"moon-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.5
		specular 0.009 roughness 0.03
	}
	rotate -6.688*z // tilt?
	rotate <0,Time*(EarthYear/27.3217),0> // anti-motion to retain tilt orientation (6.688?)
	#if (Metric=no)
	translate (251655+225558)/2/MoonOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (384400+363000)/2/MoonOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/27.3217)*-y // revolution (around Earth)
	#if (Metric=no)
	translate 13048.5/MoonOrbitScale*-x // mi move to perigee
	#else
	translate 21000/MoonOrbitScale*-x // km move to perigee
	#end
	rotate (23.5+5.15)*z // inclination
}

object
{
	Moon
	// plus Earth location
	rotate <0,Time,0> // anti-motion to retain tilt orientation
	#if (Metric=no)
	translate (94509130+91402506)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (152097701+147098074)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*-y // revolution (around Sun)
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 2499813/InnerOrbitsScale*-x //km move to perihelion
	#end
#if (Photons=yes)
	photons
	{
		target
		reflection off
		refraction on
		collect on
	}
#end
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(251655+225558)/2/MoonOrbitScale // mi aphelion and perihelion average
	#else
	(384400+363000)/2/MoonOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 13048.5/MoonOrbitScale*-x // mi move to perigee
	#else
	translate 21000/MoonOrbitScale*-x // km move to perigee
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	7860/InnerPlanetsScale
	#else
	12756/InnerPlanetsScale
	#end
	#if (Metric=no)
	translate 2902/InnerPlanetsScale
	#else
	translate 4670/InnerPlanetsScale
	#end
}
pigment
{
	rgbt <0.75,0.75,0.75,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate (23.5+5.15)*z // inclination
	rotate <0,Time,0> // anti-motion to retain tilt orientation
	#if (Metric=no)
	translate (94509130+91402506)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (152097701+147098074)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion
	#end
	rotate Time*-y // revolution (around Sun)
no_shadow
}
#end

#end

#if (ViewPoint!=4)

#declare Mars=
// MARS
/*
rotation 1.025957 days; tilt 25.19; orbit 24.077 km/sec; 686.971 days;
inclination 1.85 (5.65 Sun's equator); ascending node 49.562; arg. perihelion 286.537;
*/
sphere
{
	0,
	#if (Metric=no)
	4220/InnerPlanetsScale
	#else
	6792/InnerPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"mars-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.6
		specular 0.02 roughness 0.1
	}
	rotate Time*(EarthYear/1.025957)*-y // rotation
	rotate <25.19,Time*(EarthYear/686.971),0> // orbit anti-motion (for axial tilt hold) and axial tilt (x rotation)
	#if (Metric=no)
	translate (154851480+128418163)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (249209300+206669000)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/686.971)*-y // revolution
	#if (Metric=no)
	translate 13216658.5/InnerOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 21270150/InnerOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
	rotate 1.85*z // orbital inclination
}

object
{
	Mars
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(154851480+128418163)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(249209300+206669000)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 13216658.5/InnerOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 21270150/InnerOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(94509130+91402506)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(152097701+147098074)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <1,0.5,0,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 1.85*z // orbital inclination
no_shadow
}
#end

#end

#if (ViewPoint!=4.5)

#declare Ceres=
// CERES 
/*
rotation 0.3781 days; tilt 3; orbit 17.882 km/sec; 1679.819 days;
inclination 10.586712; ascending node 80.40696; arg. perihelion 73.15073
*/
sphere
{
	0,
	#if (Metric=no)
	302.8/DwarfPlanetsScale // 282.5 polar radius mi
	#else
	487.3/DwarfPlanetsScale // 454.7 polar radius km
	#end
	pigment
	{
		image_map
		{
			jpeg
			"ceres-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.6
		specular 0.02 roughness 0.1
	}
	rotate Time*(EarthYear/0.3781)*-y // rotation
	rotate <3,Time*(EarthYear/1679.819),0> // orbit anti-motion (for axial tilt hold) and axial tilt (x rotation)
	#if (Metric=no)
	translate (278273734+237003140)/2/AsteroidOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (447838164+381419582)/2/AsteroidOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/1679.819)*-y // revolution
	#if (Metric=no)
	translate 20635297/AsteroidOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 33209291/AsteroidOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
	rotate 10.586712*z // orbital inclination
}

object
{
	Ceres
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(278273734+237003140)/2/AsteroidOrbitsScale // mi aphelion and perihelion average
	#else
	(447838164+381419582)/2/AsteroidOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 20635297/AsteroidOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 33209291/AsteroidOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(154851480+128418163)/2/InnerOrbitsScale // mi aphelion and perihelion average
	#else
	(249209300+206669000)/2/InnerOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 13216658.5/InnerOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 21270150/InnerOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
}
pigment
{
	rgbt <1,0.5,0.5,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 10.586712*z // orbital inclination
no_shadow
}
#end

#end

#if (ViewPoint!=5)

#declare Jupiter=
// JUPITER
/*
rotation 0.413541667 day; tilt 3.13; orbit 13.07 km/sec; 4331.572 days;
inclination 1.305 (6.09 Sun's equator); ascending node 100.492; arg. perihelion 275.066;
*/
sphere
{
	0,
	#if (Metric=no)
	88846/GasGiantPlanetsScale // 41541 polar radius
	#else
	142984/GasGiantPlanetsScale // 66854 polar radius
	#end
	pigment
	{
		image_map
		{
			jpeg
			"jupiter-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.8
		specular 0.04 roughness 0.1
	}
	scale <1.0125,0.9875,1> // flattening (not fact-based)
	rotate Time*(EarthYear/0.413541667)*-y // rotation
	rotate <3.13,Time*(EarthYear/4331.572),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (507362503+460148731)/2/JupiterOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (816520800+740537600)/2/JupiterOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/4331.572)*-y // revolution
	#if (Metric=no)
	translate 23606886/JupiterOrbitScale*-x // mi move to perihelion point
	#else
	translate 37991600/JupiterOrbitScale*-x // km move to perihelion point
	#end
	rotate 1.305*z // orbit inclination
}

object
{
	Jupiter
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(507362503+460148731)/2/JupiterOrbitScale // mi aphelion and perihelion average
	#else
	(816520800+740537600)/2/JupiterOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 23606886/JupiterOrbitScale*-x // mi move to perihelion point
	#else
	translate 37991600/JupiterOrbitScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(278273734+237003140)/2/AsteroidOrbitsScale // mi aphelion and perihelion average
	#else
	(447838164+381419582)/2/AsteroidOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 20635297/AsteroidOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 33209291/AsteroidOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
}
pigment
{
	rgbt <1,0,1,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 1.305*z // orbit inclination
no_shadow
}
#end

#end

#if (ViewPoint!=6)

#declare Saturn=
// SATURN
/*
rotation 0.444 day; tilt 26.73; orbit 9.69 km/sec; 10832.327 days;
inclination 2.48524 (5.51 Sun's equator); ascending node 113.642 811; arg. perihelion 336.013 862;
*/
union
{
sphere
{
	0,
	#if (Metric=no)
	74898/GasGiantPlanetsScale // polar radius 33780 mi
	#else
	120534/GasGiantPlanetsScale // polar radius 54364 km
	#end
	pigment
	{
		image_map
		{
			jpeg
			"saturn-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.8
		specular 0.04 roughness 0.1
	}
	scale <1.025,0.975,1> // flattening (not fact-based)
	rotate Time*(EarthYear/0.444)*-y // rotation
}
disc // rings (not fact-based)
{
	0,y,
	#if (Metric=no)
	155000/GasGiantPlanetsScale,
	55000/GasGiantPlanetsScale
	#else
	249448/GasGiantPlanetsScale,
	88514/GasGiantPlanetsScale
	#end
	pigment
	{
		onion
		color_map
		{
			[0.6 rgbt <0.75,0.5,0.25,1>]
			[0.75 rgbt <0.75,0.5,0.25,0>]
			[0.8 rgb <0.75,0.5,0.25>]
			[0.85 rgb <0.75,0.75,0.5>]
			[0.9125 rgb <0.75,0.75,0.5>]
			[0.925 rgbt 1]
			[0.95 rgbt 1]
			[0.967 rgb <0.75,0.75,0.25>]
		}
		#if (Metric=no)
		scale 155000/GasGiantPlanetsScale
		#else
		scale 249448/GasGiantPlanetsScale
		#end
	}
	finish
	{
		ambient 0.01 diffuse 0.9
		specular 0.06 roughness 0.03
	}
}
	rotate <26.73,Time*(EarthYear/10832.327),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (940337046+841071241)/2/SaturnOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (1513325783+1353572956)/2/SaturnOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/10832.327)*-y // revolution
	#if (Metric=no)
	translate 49632902.5/SaturnOrbitScale*-x // mi move to perihelion point
	#else
	translate 79876414/SaturnOrbitScale*-x // km move to perihelion point
	#end
	rotate 2.48524*z // orbit inclination
}

object
{
	Saturn
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(940337046+841071241)/2/SaturnOrbitScale // mi aphelion and perihelion average
	#else
	(1513325783+1353572956)/2/SaturnOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 49632902.5/SaturnOrbitScale*-x // mi move to perihelion point
	#else
	translate 79876414/SaturnOrbitScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(507362503+460148731)/2/JupiterOrbitScale // mi aphelion and perihelion average
	#else
	(816520800+740537600)/2/JupiterOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 23606886/JupiterOrbitScale*-x // mi move to perihelion point
	#else
	translate 37991600/JupiterOrbitScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <1,1,0,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 2.48524*z // orbit inclination
no_shadow
}
#end

#end

#if (ViewPoint!=7)

#declare Uranus=
// URANUS
/*
rotation -0.71833 day; tilt 97.77; orbit 6.81 km/sec; 30799.095 days;
inclination 0.772556 (6.48 sun's equator); ascending node 73.989821; arg. perihelion 96.541318;
*/
union
{
sphere
{
	0,
	#if (Metric=no)
	31763/GasGiantPlanetsScale // 31035 mi polar radius
	#else
	51118/GasGiantPlanetsScale // 49946 km polar radius
	#end
	pigment
	{
		image_map
		{
			jpeg
			"uranus-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.7
		specular 0.04 roughness 0.1
	}
	rotate Time*(EarthYear/0.71833)*-y // rotation
}
disc // rings (not fact-based)
{
	0,y,
	#if (Metric=no)
	64000/GasGiantPlanetsScale,
	44000/GasGiantPlanetsScale
	#else
	102998/GasGiantPlanetsScale,
	70811/GasGiantPlanetsScale
	#end
	pigment
	{
		onion
		color_map
		{
			[0.67 rgbt <0.5,0.5,0.25,1>]
			[0.7 rgbt <0.5,0.5,0.25,0>]
			[0.7 rgbt 1]
			[0.775 rgb 1]
			[0.8 rgb <0.5,0.5,0.25>]
			[0.825 rgbt 1]
			[0.85 rgbt 1]
			[0.875 rgb <0.5,0.5,0.5>]
			[0.9 rgb <0.5,0.5,0.5>]
			[0.9 rgbt 1]
			[0.975 rgbt 1]
			[1 rgb <0.5,0.5,0.25>]
		}
		#if (Metric=no)
		scale 64000/GasGiantPlanetsScale
		#else
		scale 102998/GasGiantPlanetsScale
		#end
	}
	finish
	{
		ambient 0.01 diffuse 0.4
		specular 0.02 roughness 0.08
	}
}
	transform
	{
	rotate <97.77,Time*(EarthYear/30799.095),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (1866859854+1708111169)/2/UranusOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (3004419704+2748938461)/2/UranusOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/30799.095)*-y // revolution
	#if (Metric=no)
	translate 79374342.5/UranusOrbitScale*-x // mi move to perihelion point
	#else
	translate 127740622/UranusOrbitScale*-x // km move to perihelion point
	#end
	rotate 0.772556*z // orbit inclination
	}
}

object
{
	Uranus
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(1866859854+1708111169)/2/UranusOrbitScale // mi aphelion and perihelion average
	#else
	(3004419704+2748938461)/2/UranusOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 49632902.5/SaturnOrbitScale*-x // mi move to perihelion point
	#else
	translate 79876414/SaturnOrbitScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(940337046+841071241)/2/SaturnOrbitScale // mi aphelion and perihelion average
	#else
	(1513325783+1353572956)/2/SaturnOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 49632902.5/SaturnOrbitScale*-x // mi move to perihelion point
	#else
	translate 79876414/SaturnOrbitScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <0,1,0.5,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 0.772556*z // orbit inclination
no_shadow
}
#end

#end

#if (ViewPoint!=8)

#declare Neptune=
// NEPTUNE
/*
rotation 0.6713 day; tilt 28.32; orbit 5.43 km/sec; 60190 days;
inclination 1.767975 (6.43 sun's equator); ascending node 131.794310; arg. perihelion 265.646853
*/
sphere
{
	0,
	#if (Metric=no)
	30775/GasGiantPlanetsScale // 30250 mi polar radius
	#else
	49528/GasGiantPlanetsScale // 48682 km polar radius
	#end
	pigment
	{
		image_map
		{
			jpeg
			"neptune-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.7
		specular 0.04 roughness 0.1
	}
	rotate Time*(EarthYear/0.6713)*-y // rotation
	rotate <28.32,Time*(EarthYear/60190),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (2829691160+2766929154)/2/OuterOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (4553946490+4452940833)/2/OuterOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/60190)*-y // revolution
	#if (Metric=no)
	translate 31381003/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 50502829/OuterOrbitsScale*-x // km move to perihelion point
	#end
	rotate 1.767975*z // orbit inclination
}

object
{
	Neptune
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(2829691160+2766929154)/2/OuterOrbitsScale // mi aphelion and perihelion average
	#else
	(4553946490+4452940833)/2/OuterOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 31381003/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 50502829/OuterOrbitsScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(1866859854+1708111169)/2/UranusOrbitScale // mi aphelion and perihelion average
	#else
	(3004419704+2748938461)/2/UranusOrbitScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 79374342.5/UranusOrbitScale*-x // mi move to perihelion point
	#else
	translate 127740622/UranusOrbitScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <0,0.5,1,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 1.767975*z // orbit inclination
no_shadow
}
#end

#end

#if (ViewPoint!=9)

#declare PlutoCharon=
// PLUTO/CHARON
union
{
// PLUTO
/*
rotation 6.387 days; tilt 119.591; orbit 4.666 km/sec; 90613.3 days;
inclination 17.14175 (11.88 sun's equator); ascending node 110.30347; arg. perihelion 113.76329;
*/
sphere
{
	0,
	#if (Metric=no)
	1485/DwarfPlanetsScale
	#else
	2390/DwarfPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"pluto-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.8
		specular 0.05 roughness 0.07
	}
	#if (Metric=no)
	translate 1264.5/CharonOrbitScale*-x // miles
	#else
	translate 2035/CharonOrbitScale*-x // kilometers
	#end
}
// CHARON
/*
rotation 6.387 days; tilt 112.783 to ecliptic (0.001 to Pluto's equator);
*/
sphere
{
	0,
	#if (Metric=no)
	750/DwarfPlanetsScale
	#else
	1207/DwarfPlanetsScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"charon-map"
			map_type 1
		}
	}
	finish
	{
		ambient 0.001 diffuse 0.7
		specular 0.04 roughness 0.08
	}
	#if (Metric=no)
	translate (12161-1264.5)/CharonOrbitScale*x // miles
	#else
	translate (19571-2035)/CharonOrbitScale*x // kilometers
	#end
}
	rotate <0,Time*(EarthYear/6.387),0> // planet/moon orbit
	rotate 119.591*x // Pluto/Charon mutual orbit inclination

	rotate <0,Time*(EarthYear/90613.3),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (4583000000+2757000000)/2/OuterOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (7376000000+4437000000)/2/OuterOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/90613.3)*-y // revolution
	#if (Metric=no)
	translate 913000000/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 1469331072/OuterOrbitsScale*-x // km move to perihelion point
	#end
	rotate 17.14175*z // orbit inclination
}

object
{
	PlutoCharon
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(4583000000+2757000000)/2/OuterOrbitsScale // mi aphelion and perihelion average
	#else
	(7376000000+4437000000)/2/OuterOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 913000000/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 1469331072/OuterOrbitsScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(2829691160+2766929154)/2/OuterOrbitsScale // mi aphelion and perihelion average
	#else
	(4553946490+4452940833)/2/OuterOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 31381003/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 50502829/OuterOrbitsScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <0,0,1,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 17.14175*z // orbit inclination
no_shadow
}
#end

#end

#if (ViewPoint!=10)

#declare Eris=
// ERIS/DYSNOMIA
union
{
// ERIS
/*
rotation 1/3 days; tilt ?; orbit 3.436 km/sec; 203334.675 days;
inclination 44.187; ascending node 35.8696; arg. perihelion 151.4305
*/
sphere
{
	0,
	#if (Metric=no)
	1677.7/DwarfPlanetsScale
	#else
	2700/DwarfPlanetsScale
	#end
	pigment
	{
		wrinkles
		color_map
		{
			[0 rgb <0.4,0.35,0.3>/2]
			[0.2 rgb <0.45,0.35,0.3>]
			[0.7 rgb <0.35,0.35,0.35>]
			[1 rgb <0.35,0.35,0.35>*2]
		}
		scale 0.75
	}
	finish
	{
		ambient 0.001 diffuse 0.6
		specular 0.03 roughness 0.09
	}
	rotate <0,Time*(EarthYear/0.333333),0>
}
// DYSNOMIA
sphere
{
	0,
	#if (Metric=no)
	124/DwarfPlanetsScale
	#else
	200/DwarfPlanetsScale
	#end
	pigment
	{
		wrinkles
		color_map
		{
			[0 rgb <0.4,0.4,0.4>/2]
			[0.3 rgb <0.45,0.35,0.35>]
			[0.6 rgb <0.3,0.25,0.2>]
			[1 rgb <0.3,0.25,0.2>*2]
		}
		scale 0.05
	}
	finish
	{
		ambient 0.001 diffuse 0.5
		specular 0.02 roughness 0.1
	}
	#if (Metric=no)
	translate 23221/DysnomiaOrbitScale*x // miles moon orbit distance
	#else
	translate 37370/DysnomiaOrbitScale*x // kilometers moon orbit distance
	#end
	rotate <0,Time*(EarthYear/15.774),142> // moon orbit and inclination
}
	rotate <0,Time*(EarthYear/203334.675),0> // anti-revolution retains tilt orientation
	#if (Metric=no)
	translate (9.072e9+3.51e9)/2/OuterOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (14.6e9+5.65e9)/2/OuterOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/203334.675)*-y // revolution
	#if (Metric=no)
	translate 2.781e9/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 4.4756e9/OuterOrbitsScale*-x // km move to perihelion point
	#end
	rotate 44.187*z // orbit inclination
}

object
{
	Eris
}

#if (ShowOrbitalPlanes=yes)
difference
{
cylinder
{
	-y/10,y/10,
	#if (Metric=no)
	(9.072e9+3.51e9)/2/OuterOrbitsScale // mi aphelion and perihelion average
	#else
	(14.6e9+5.65e9)/2/OuterOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 2.781e9/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 4.4756e9/OuterOrbitsScale*-x // km move to perihelion point
	#end
}
cylinder
{
	-y,y,
	#if (Metric=no)
	(4583000000+2757000000)/2/OuterOrbitsScale // mi aphelion and perihelion average
	#else
	(7376000000+4437000000)/2/OuterOrbitsScale // km aphelion and perihelion average
	#end
	#if (Metric=no)
	translate 913000000/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 1469331072/OuterOrbitsScale*-x // km move to perihelion point
	#end
}
pigment
{
	rgbt <1,0,0,OrbitalPlanesTransparency>
}
finish
{
	ambient 1 diffuse 0
}
	rotate 44.187*z // orbit inclination
no_shadow
}
#end

#end

#end // all or one planet switch


/* Camera Views */

#declare SunView=
transform
{
}

#declare MercuryView=
transform
{
	#if (Metric=no)
	translate (43382210+28583820)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (69816900+46001200)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/87.969)*-y // revolution
	#if (Metric=no)
	translate 7399195/InnerOrbitsScale*-x // mi
	#else
	translate 11907850/InnerOrbitsScale*-x // km
	#end
	rotate 7.005*z // orbit inclination
}

#declare VenusView=
transform
{
	#if (Metric=no)
	translate (67693488+66782651)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (108942109+107476259)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/224.70069)*-y // revolution
	#if (Metric=no)
	translate 455418.5/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 732925/InnerOrbitsScale*-x // km move to perihelion point
	#end
	rotate 3.39471*z // orbit inclination
}

#declare EarthMoonView=
transform
{
	#if (Metric=no)
	translate (94509130+91402506)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (152097701+147098074)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*-y // revolution
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion point
	#end
}

#declare EarthView=
transform
{
	#if (Metric=no)
	translate (94509130+91402506)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (152097701+147098074)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*-y // revolution
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi move to perihelion point
	#else
	translate 2499813/InnerOrbitsScale*-x // km move to perihelion point
	#end
}

#declare MoonView=
transform
{
	#if (Metric=no)
	translate (251655+225558)/2/MoonOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (384400+363000)/2/MoonOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/27.3217)*-y // revolution (around Earth)
	#if (Metric=no)
	translate 13048.5/MoonOrbitScale*-x // mi
	#else
	translate 21000/MoonOrbitScale*-x // km
	#end
	rotate (23.5+5.15)*z // inclination

	// plus Earth location
	#if (Metric=no)
	translate (94509130+91402506)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (152097701+147098074)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*-y // revolution (around Sun)
	#if (Metric=no)
	translate 1553312/InnerOrbitsScale*-x // mi
	#else
	translate 2499813/InnerOrbitsScale*-x //km
	#end
}

#declare MarsView=
transform
{
	#if (Metric=no)
	translate (154851480+128418163)/2/InnerOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (249209300+206669000)/2/InnerOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/686.971)*-y // revolution
	#if (Metric=no)
	translate 13216658.5/InnerOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 21270150/InnerOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
	rotate 1.85*z // orbital inclination
}

#declare CeresView=
transform
{
	#if (Metric=no)
	translate (278273734+237003140)/2/AsteroidOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (447838164+381419582)/2/AsteroidOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/1679.819)*-y // revolution
	#if (Metric=no)
	translate 20635297/AsteroidOrbitsScale*-x // mi orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#else
	translate 33209291/AsteroidOrbitsScale*-x // km orbit offset (after subtraction of perihelion from aphelion plus perihelion average)
	#end
	rotate 10.586712*z // orbital inclination
}

#declare JupiterView=
transform
{
	#if (Metric=no)
	translate (507362503+460148731)/2/JupiterOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (816520800+740537600)/2/JupiterOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/4331.572)*-y // revolution
	#if (Metric=no)
	translate 23606886/JupiterOrbitScale*-x // mi move to perihelion point
	#else
	translate 37991600/JupiterOrbitScale*-x // km move to perihelion point
	#end
	rotate 1.305*z // orbit inclination
}

#declare SaturnView=
transform
{
	#if (Metric=no)
	translate (940337046+841071241)/2/SaturnOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (1513325783+1353572956)/2/SaturnOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/10832.327)*-y // revolution
	#if (Metric=no)
	translate 49632902.5/SaturnOrbitScale*-x // mi move to perihelion point
	#else
	translate 79876414/SaturnOrbitScale*-x // km move to perihelion point
	#end
	rotate 2.48524*z // orbit inclination
}

#declare UranusView=
transform
{
	#if (Metric=no)
	translate (1866859854+1708111169)/2/UranusOrbitScale*x // mi aphelion and perihelion average
	#else
	translate (3004419704+2748938461)/2/UranusOrbitScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/30799.095)*-y // revolution
	#if (Metric=no)
	translate 79374342.5/UranusOrbitScale*-x // mi move to perihelion point
	#else
	translate 127740622/UranusOrbitScale*-x // km move to perihelion point
	#end
	rotate 0.772556*z // orbit inclination
}

#declare NeptuneView=
transform
{
	#if (Metric=no)
	translate (2829691160+2766929154)/2/OuterOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (4553946490+4452940833)/2/OuterOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/60190)*-y // revolution
	#if (Metric=no)
	translate 31381003/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 50502829/OuterOrbitsScale*-x // km move to perihelion point
	#end
	rotate 1.767975*z // orbit inclination
}

#declare PlutoView=
transform
{
	#if (Metric=no)
	translate (4583000000+2757000000)/2/OuterOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (7376000000+4437000000)/2/OuterOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/90613.3)*-y // revolution
	#if (Metric=no)
	translate 913000000/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 1469331072/OuterOrbitsScale*-x // km move to perihelion point
	#end
	rotate 17.14175*z // orbit inclination
}

#declare ErisView=
transform
{
	#if (Metric=no)
	translate (9.072e9+3.51e9)/2/OuterOrbitsScale*x // mi aphelion and perihelion average
	#else
	translate (14.6e9+5.65e9)/2/OuterOrbitsScale*x // km aphelion and perihelion average
	#end
	rotate Time*(EarthYear/203334.675)*-y // revolution
	#if (Metric=no)
	translate 2.781e9/OuterOrbitsScale*-x // mi move to perihelion point
	#else
	translate 4.4756e9/OuterOrbitsScale*-x // km move to perihelion point
	#end
	rotate 44.187*z // orbit inclination
}

/* @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@ */

#declare SolarFlares=
density
{
	marble
	density_map
	{
		[0.45 rgb 0]
		[0.475 rgb <1,0.25,0.1>]
		[0.525 rgb <1,0.75,0.1>]
		[0.55 rgb 0]
	}
	turbulence 0.5
	phase clock
	rotate <60,-30,-60>
}

// SUN
/* rotation 25.38 days (at equator) */
#declare Sun=
union
{
sphere
{
	0,
	#if (Metric=no)
	864900/SunScale
	#else
	1392000/SunScale
	#end
	pigment
	{
		image_map
		{
			jpeg
			"sun-map"
			map_type 1
		}
	}
	finish
	{
		ambient 1 diffuse 0
	}
}
sphere
{
	0,
	#if (Metric=no)
	1000000/SunScale
	#else
	1620000/SunScale
	#end
	pigment
	{
		rgbt 1
	}
	interior
	{
		media
		{
			emission 1
			density
			{
				spherical
				density_map
				{
					[0 rgb 0]
					[0.2 SolarFlares]
				}
			}
			#if (Metric=no)
			scale 1000000/SunScale
			#else
			scale 1620000/SunScale
			#end
		}
	}
	hollow on
}
	rotate Time*(EarthYear/25.38)*-y // rotation
}

light_source
{
	0,
	1 // greater than 1 shows distant planets better
	#if (ParallelLight=yes)
	parallel
	point_at 62*x
	#end // parallel point at
	looks_like
	{
		Sun
	}
	#if (Metric=no)
	area_light <17.3,0,0>*(1e5/SunScale),<0,0,17.3>*(1e5/SunScale), 12, 12 jitter adaptive 1 circular orient
	#else
	area_light <27.84,0,0>*(1e5/SunScale),<0,0,27.84>*(1e5/SunScale), 12, 12 jitter adaptive 1 circular orient
	#end
	fade_distance 62*(1e5/SunScale) fade_power 2 // using Earth location (62*x) as a reference point
	#if (Atmosphere=yes)
	media_interaction on media_attenuation on
	#end
#if (Photons=yes)
	photons
	{
		reflection off
		refraction on
	}
#end

	#if (Metric=no)
	translate 4324.5/SunScale*-x // Sun/Earth barycenter mi
	#else
	translate 6959.6/SunScale*-x // Sun/Earth barycenter km
	#end
	rotate Time*-y

	#if (Metric=no)
	translate 461057.4/SunScale*-x // Sun/Jupiter barycenter mi
	#else
	translate 742000/SunScale*-x // Sun/Jupiter barycenter km
	#end
	rotate Time*(EarthYear/4331.572)*-y // Jupiter-coupled revolution around barycenter
	
	#if (Metric=no)
	translate 253415.7/SunScale*-x // Sun/Saturn barycenter mi
	#else
	translate 407833/SunScale*-x // Sun/Saturn barycenter km
	#end
	rotate Time*(EarthYear/10832.327)*-y
	
	#if (Metric=no)
	translate 77841/SunScale*-x // Sun/Uranus barycenter mi
	#else
	translate 125272.95/SunScale*-x // Sun/Uranus barycenter km
	#end
	rotate Time*(EarthYear/30799.095)*-y
	
	#if (Metric=no)
	translate 144870.75/SunScale*-x // Sun/Neptune barycenter mi
	#else
	translate 233146.87/SunScale*-x // Sun/Neptune barycenter km
	#end
	rotate Time*(EarthYear/60190)*-y
}

/* &&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&& */

camera
{
	//orthographic
	#if (Metric=no)
	location -750*ViewScale*z
	#else
	location -1207*ViewScale*z
	#end
	up y
	right x
	look_at 0
	angle 67*Zoom
	rotate <ViewElevation,-ViewAzimuth,0>
transform
{
#switch (ViewPoint)
#case (-3)
EarthView
#break
#case (-1)
MoonView
#break
#case (0)
SunView
#break
#case (1)
MercuryView
#break
#case (2)
VenusView
#break
#case (3)
EarthMoonView
#break
#case (4)
MarsView
#break
#case (4.5)
CeresView
#break
#case (5)
JupiterView
#break
#case (6)
SaturnView
#break
#case (7)
UranusView
#break
#case (8)
NeptuneView
#break
#case (9)
PlutoView
#break
#case (10)
ErisView
#break
#end
} // end transform

} // end camera

/* END OF SCENE FILE */
